test suite reviews and discussions
 help / color / mirror / Atom feed
* [dts] [PATCH] tests/vf_offload: correct case grammar and sw checksum test
@ 2019-03-18  3:57 Xueqin Lin
  2019-03-24 18:32 ` Tu, Lijuan
  0 siblings, 1 reply; 2+ messages in thread
From: Xueqin Lin @ 2019-03-18  3:57 UTC (permalink / raw)
  To: dts; +Cc: Xueqin Lin

Signed-off-by: Xueqin Lin <xueqin.lin@intel.com>

---
 tests/TestSuite_vf_offload.py | 27 +++++++++++++++------------
 1 file changed, 15 insertions(+), 12 deletions(-)

diff --git a/tests/TestSuite_vf_offload.py b/tests/TestSuite_vf_offload.py
index cb4b368..8cb0dac 100644
--- a/tests/TestSuite_vf_offload.py
+++ b/tests/TestSuite_vf_offload.py
@@ -27,7 +27,7 @@ class TestVfOffload(TestCase):
         self.vf_driver = self.get_suite_cfg()['vf_driver']
         if self.vf_driver is None:
             self.vf_driver = 'pci-stub'
-        self.verify(self.vf_driver in self.supported_vf_driver, "Unspported vf driver")
+        self.verify(self.vf_driver in self.supported_vf_driver, "Unsupported vf driver")
         if self.vf_driver == 'pci-stub':
             self.vf_assign_method = 'pci-assign'
         else:
@@ -126,10 +126,12 @@ class TestVfOffload(TestCase):
         dut.send_expect("port start all", "testpmd>")
 
     def checksum_enablesw(self, port, dut):
+        dut.send_expect("port stop all", "testpmd>")
         dut.send_expect("csum set ip sw %d" % port, "testpmd>")
         dut.send_expect("csum set udp sw %d" % port, "testpmd>")
         dut.send_expect("csum set tcp sw %d" % port, "testpmd>")
         dut.send_expect("csum set sctp sw %d" % port, "testpmd>")
+        dut.send_expect("port start all", "testpmd>")
 
     def checksum_validate(self, packets_sent, packets_expected):
         """
@@ -202,10 +204,10 @@ class TestVfOffload(TestCase):
 
     def test_checksum_offload_enable(self):
         """
-        Enable HW Checksum offload.
-        Send packet with incorrect checksum, 
-        can rx it and reported the checksum error, 
-        verify forwarded packets have correct checksum
+        Enable HW checksum offload.
+        Send packet with incorrect checksum,
+        can rx it and report the checksum error,
+        verify forwarded packets have correct checksum.
         """
         self.vm0_testpmd.start_testpmd(VM_CORES_MASK, "--portmask=%s " %
                                       (self.portMask) + "--enable-rx-cksum " + "" +
@@ -252,8 +254,7 @@ class TestVfOffload(TestCase):
 
     def test_checksum_offload_disable(self):
         """
-        disable HW checksum offload on tx port, SW Checksum check.
-        SW Checksum on by default.
+        Enable SW checksum offload.
         Send same packet with incorrect checksum and verify checksum is valid.
         """
 
@@ -279,6 +280,8 @@ class TestVfOffload(TestCase):
                    'IPv6/UDP': 'Ether(dst="02:00:00:00:00:00", src="%s")/IPv6(src="%s")/UDP()/("X"*46)' % (mac, expIPv6),
                    'IPv6/TCP': 'Ether(dst="02:00:00:00:00:00", src="%s")/IPv6(src="%s")/TCP()/("X"*46)' % (mac, expIPv6)}
 
+        self.checksum_enablesw(0, self.vm_dut_0)
+
         self.vm0_testpmd.execute_cmd('start')
         result = self.checksum_validate(sndPkts, expPkts)
 
@@ -293,7 +296,7 @@ class TestVfOffload(TestCase):
 
     def tcpdump_start_sniffing(self, ifaces=[]):
         """
         Starts tcpdump in the background to sniff the tester interface where
         the packets are transmitted to and from the self.dut.
         All the captured packets are going to be stored in a file for a
         post-analysis.
@@ -306,7 +309,7 @@ class TestVfOffload(TestCase):
 
     def tcpdump_stop_sniff(self):
         """
         Stops the tcpdump process running in the background.
         """
         self.tester.send_expect('killall tcpdump', '#')
         time.sleep(1)
@@ -315,7 +318,7 @@ class TestVfOffload(TestCase):
 
     def tcpdump_command(self, command):
         """
         Sends a tcpdump related command and returns an integer from the output
         """
 
         result = self.tester.send_expect(command, '#')
@@ -324,7 +327,7 @@ class TestVfOffload(TestCase):
 
     def number_of_packets(self, iface):
         """
-        By reading the file generated by tcpdump it counts how many packets were
+        By reading the file generated by tcpdump it counts how many packets are
         forwarded by the sample app and received in the self.tester. The sample app
         will add a known MAC address for the test to look for.
         """
@@ -335,7 +338,7 @@ class TestVfOffload(TestCase):
 
     def test_tso(self):
         """
-        TSO IPv4 TCP, IPv6 TCP, VXLan testing
+        TSO IPv4 TCP, IPv6 TCP testing.
         """
         tx_interface = self.tester.get_interface(self.tester.get_local_port(self.dut_ports[0]))
         rx_interface = self.tester.get_interface(self.tester.get_local_port(self.dut_ports[1]))
@@ -293,7 +296,7 @@ class TestVfOffload(TestCase):
     def tcpdump_start_sniffing(self, ifaces=[]):
         """
-        Starts tcpdump in the background to sniff the tester interface where
+        Start tcpdump in the background to sniff the tester interface where
         the packets are transmitted to and from the self.dut.
         All the captured packets are going to be stored in a file for a
@@ -306,7 +309,7 @@ class TestVfOffload(TestCase):
     def tcpdump_stop_sniff(self):
         """
-        Stops the tcpdump process running in the background.
+        Stop the tcpdump process running in the background.
         """
         self.tester.send_expect('killall tcpdump', '#')
@@ -315,7 +318,7 @@ class TestVfOffload(TestCase):
     def tcpdump_command(self, command):
         """
-        Sends a tcpdump related command and returns an integer from the output
+        Send a tcpdump related command and return an integer from the output.
         """
 
-- 
2.5.5


^ permalink raw reply	[flat|nested] 2+ messages in thread

* Re: [dts] [PATCH] tests/vf_offload: correct case grammar and sw checksum test
  2019-03-18  3:57 [dts] [PATCH] tests/vf_offload: correct case grammar and sw checksum test Xueqin Lin
@ 2019-03-24 18:32 ` Tu, Lijuan
  0 siblings, 0 replies; 2+ messages in thread
From: Tu, Lijuan @ 2019-03-24 18:32 UTC (permalink / raw)
  To: Lin, Xueqin, dts; +Cc: Lin, Xueqin

Applied, thanks

> -----Original Message-----
> From: dts [mailto:dts-bounces@dpdk.org] On Behalf Of Xueqin Lin
> Sent: Sunday, March 17, 2019 8:58 PM
> To: dts@dpdk.org
> Cc: Lin, Xueqin <xueqin.lin@intel.com>
> Subject: [dts] [PATCH] tests/vf_offload: correct case grammar and sw checksum
> test
> 
> Signed-off-by: Xueqin Lin <xueqin.lin@intel.com>
> 
> ---
>  tests/TestSuite_vf_offload.py | 27 +++++++++++++++------------
>  1 file changed, 15 insertions(+), 12 deletions(-)
> 
> diff --git a/tests/TestSuite_vf_offload.py b/tests/TestSuite_vf_offload.py index
> cb4b368..8cb0dac 100644
> --- a/tests/TestSuite_vf_offload.py
> +++ b/tests/TestSuite_vf_offload.py
> @@ -27,7 +27,7 @@ class TestVfOffload(TestCase):
>          self.vf_driver = self.get_suite_cfg()['vf_driver']
>          if self.vf_driver is None:
>              self.vf_driver = 'pci-stub'
> -        self.verify(self.vf_driver in self.supported_vf_driver, "Unspported vf driver")
> +        self.verify(self.vf_driver in self.supported_vf_driver,
> + "Unsupported vf driver")
>          if self.vf_driver == 'pci-stub':
>              self.vf_assign_method = 'pci-assign'
>          else:
> @@ -126,10 +126,12 @@ class TestVfOffload(TestCase):
>          dut.send_expect("port start all", "testpmd>")
> 
>      def checksum_enablesw(self, port, dut):
> +        dut.send_expect("port stop all", "testpmd>")
>          dut.send_expect("csum set ip sw %d" % port, "testpmd>")
>          dut.send_expect("csum set udp sw %d" % port, "testpmd>")
>          dut.send_expect("csum set tcp sw %d" % port, "testpmd>")
>          dut.send_expect("csum set sctp sw %d" % port, "testpmd>")
> +        dut.send_expect("port start all", "testpmd>")
> 
>      def checksum_validate(self, packets_sent, packets_expected):
>          """
> @@ -202,10 +204,10 @@ class TestVfOffload(TestCase):
> 
>      def test_checksum_offload_enable(self):
>          """
> -        Enable HW Checksum offload.
> -        Send packet with incorrect checksum,
> -        can rx it and reported the checksum error,
> -        verify forwarded packets have correct checksum
> +        Enable HW checksum offload.
> +        Send packet with incorrect checksum,
> +        can rx it and report the checksum error,
> +        verify forwarded packets have correct checksum.
>          """
>          self.vm0_testpmd.start_testpmd(VM_CORES_MASK, "--portmask=%s " %
>                                        (self.portMask) + "--enable-rx-cksum " + "" + @@ -252,8
> +254,7 @@ class TestVfOffload(TestCase):
> 
>      def test_checksum_offload_disable(self):
>          """
> -        disable HW checksum offload on tx port, SW Checksum check.
> -        SW Checksum on by default.
> +        Enable SW checksum offload.
>          Send same packet with incorrect checksum and verify checksum is valid.
>          """
> 
> @@ -279,6 +280,8 @@ class TestVfOffload(TestCase):
>                     'IPv6/UDP': 'Ether(dst="02:00:00:00:00:00",
> src="%s")/IPv6(src="%s")/UDP()/("X"*46)' % (mac, expIPv6),
>                     'IPv6/TCP': 'Ether(dst="02:00:00:00:00:00",
> src="%s")/IPv6(src="%s")/TCP()/("X"*46)' % (mac, expIPv6)}
> 
> +        self.checksum_enablesw(0, self.vm_dut_0)
> +
>          self.vm0_testpmd.execute_cmd('start')
>          result = self.checksum_validate(sndPkts, expPkts)
> 
> @@ -293,7 +296,7 @@ class TestVfOffload(TestCase):
> 
>      def tcpdump_start_sniffing(self, ifaces=[]):
>          """
> -        Starts tcpdump in the background to sniff the tester interface where
> +        Start tcpdump in the background to sniff the tester interface
> + where
>          the packets are transmitted to and from the self.dut.
>          All the captured packets are going to be stored in a file for a
>          post-analysis.
> @@ -306,7 +309,7 @@ class TestVfOffload(TestCase):
> 
>      def tcpdump_stop_sniff(self):
>          """
> -        Stops the tcpdump process running in the background.
> +        Stop the tcpdump process running in the background.
>          """
>          self.tester.send_expect('killall tcpdump', '#')
>          time.sleep(1)
> @@ -315,7 +318,7 @@ class TestVfOffload(TestCase):
> 
>      def tcpdump_command(self, command):
>          """
> -        Sends a tcpdump related command and returns an integer from the output
> +        Send a tcpdump related command and return an integer from the output.
>          """
> 
>          result = self.tester.send_expect(command, '#') @@ -324,7 +327,7 @@
> class TestVfOffload(TestCase):
> 
>      def number_of_packets(self, iface):
>          """
> -        By reading the file generated by tcpdump it counts how many packets were
> +        By reading the file generated by tcpdump it counts how many
> + packets are
>          forwarded by the sample app and received in the self.tester. The sample
> app
>          will add a known MAC address for the test to look for.
>          """
> @@ -335,7 +338,7 @@ class TestVfOffload(TestCase):
> 
>      def test_tso(self):
>          """
> -        TSO IPv4 TCP, IPv6 TCP, VXLan testing
> +        TSO IPv4 TCP, IPv6 TCP testing.
>          """
>          tx_interface =
> self.tester.get_interface(self.tester.get_local_port(self.dut_ports[0]))
>          rx_interface =
> self.tester.get_interface(self.tester.get_local_port(self.dut_ports[1]))
> --
> 2.5.5


^ permalink raw reply	[flat|nested] 2+ messages in thread

end of thread, other threads:[~2019-03-24 18:32 UTC | newest]

Thread overview: 2+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2019-03-18  3:57 [dts] [PATCH] tests/vf_offload: correct case grammar and sw checksum test Xueqin Lin
2019-03-24 18:32 ` Tu, Lijuan

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).